#!/bin/bash

CMD=`basename $0`
CMDDIR=`dirname $0`
CMDDIR=`(cd $CMDDIR; pwd)`
OS_TYPE=`lsb_release -i | awk '{print $3}'`

hammr_install()  {
	# install required libs
	if [ "$OS_TYPE" =  "CentOS"  ]; then
		yum -y install wget gcc python-setuptools python-devel libxml2-devel libxslt-devel
	elif [ "$OS_TYPE" =  "Debian"  ] || [ "$OS_TYPE" =  "Ubuntu"  ] ; then
		aptitude update
		aptitude -y install wget python-setuptools python-dev gcc libxslt1-dev
	else
		echo " OS $OS_TYPE not supported"
		exit 1
	fi	

	wget https://raw.github.com/pypa/pip/master/contrib/get-pip.py
	python get-pip.py
	#install hammr
	easy_install progressbar==2.3
	pip install hammr
}

tomcat_setup()  {

	# install java jre
	if [ "$OS_TYPE" =  "CentOS"  ]; then
		yum -y install java-1.7.0-openjdk
	elif [ "$OS_TYPE" =  "Debian"  ] || [ "$OS_TYPE" =  "Ubuntu"  ] ; then
		aptitude -y  install openjdk-7-jre
	else
		echo " OS $OS_TYPE not supported"
		exit 1
	fi	
	
	# install tomcat 7
	(cd /opt ; unzip -o $CMDDIR/apache-tomcat-7.0.64.zip ; rm -Rf /opt/tomcat7 ; mkdir -p /opt/tomcat7 ; mv /opt/apache-tomcat-7.0.64/* /opt/tomcat7)
	chmod a+x /opt/tomcat7/bin/*.sh

	# create tomcat user and change user permissions
 	groupadd tomcat
	useradd -g tomcat -c "Tomcat" -r -s /bin/bash tomcat
	chown -R tomcat /opt/tomcat7

	# setup tomcat service
	if [ "$OS_TYPE" =  "CentOS"  ]; then
		if [ -d /etc/rc.d/init.d ]; then
			cp $CMDDIR/tomcat_init /etc/rc.d/init.d/tomcat
			chmod a+x /etc/rc.d/init.d/tomcat
		elif [ -d /etc/init.d ]; then
			cp $CMDDIR/tomcat_init /etc/init.d/tomcat
			chmod a+x /etc/rc.d/init.d/tomcat
		else 
			echo "Cannot find /etc/init.d directory"
			exit 1
		fi
	elif [ "$OS_TYPE" =  "Debian"  ] || [ "$OS_TYPE" =  "Ubuntu"  ] ; then
		cp $CMDDIR/tomcat_init /etc/init.d/tomcat
		chmod a+x /etc/init.d/tomcat
		update-rc.d tomcat defaults
	else
		echo " OS $OS_TYPE not supported"
		exit 1
	fi
}

ws_deploy() {
	unzip -d /opt/tomcat7/webapps/ocw-modeleur $CMDDIR/ws/ocw-modeleur.war 
	unzip -d /opt/tomcat7/webapps/opencloudware $CMDDIR/ws/opencloudware.war 
	cp $CMDDIR/config.xml /opt/tomcat7/webapps/opencloudware/
	chown -R tomcat:tomcat /opt/tomcat7/webapps/ocw-modeleur 
	chown -R tomcat:tomcat /opt/tomcat7/webapps/opencloudware
	/etc/init.d/tomcat start
	/etc/init.d/tomcat start

}

echo "Installing Hammr"
hammr_install
echo "Installing tomcat7"
tomcat_setup
echo "Deploying ocw web services"
ws_deploy

exit 0


